pub struct ExchangeEnvelope {
pub exchange: Exchange,
pub reply_tx: Option<Sender<Result<Exchange, CamelError>>>,
}Expand description
A message sent from a consumer to the route pipeline.
Fire-and-forget exchanges use reply_tx = None.
Request-reply exchanges (e.g. direct:) provide a reply_tx so the
pipeline result can be sent back to the consumer.
Fields
exchange: Exchangereply_tx: Option<Sender<Result<Exchange, CamelError>>>Auto Trait Implementations
impl !Freeze for ExchangeEnvelope
impl !RefUnwindSafe for ExchangeEnvelope
impl Send for ExchangeEnvelope
impl Sync for ExchangeEnvelope
impl Unpin for ExchangeEnvelope
impl UnsafeUnpin for ExchangeEnvelope
impl !UnwindSafe for ExchangeEnvelope