Structs
- Consumer
Context - Context provided to a Consumer, allowing it to send exchanges into the route.
- Exchange
Envelope - A message sent from a consumer to the route pipeline.
Enums
- Concurrency
Model - How a consumer’s exchanges should be processed by the pipeline.
Traits
- Consumer
- A Consumer receives messages from an external source and feeds them into the route.